#
# spec file for package bibletime
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012-2014 Lars Vogdt
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Internal QML import
%global __requires_exclude qmlimport\\(BibleTime.*

Name:           bibletime
Version:        3.0.3
Release:        2.7
Summary:        A Bible study tool
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Other
URL:            http://www.bibletime.info/
Source0:        https://github.com/bibletime/bibletime/releases/download/v%{version}/bibletime-%{version}.tar.xz
Source1:        bibletime-rpmlintrc
BuildRequires:  cmake
BuildRequires:  curl-devel
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Qml)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  pkgconfig(libclucene-core)
BuildRequires:  pkgconfig(sword) >= 1.7
# Dependencies for building documentation
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  fop
BuildRequires:  libxslt-tools
BuildRequires:  po4a
Recommends:     sword-bible
Recommends:     sword-commentary
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif

%description
BibleTime is a Bible study program.

The software uses the SWORD programming library to work with over 200 free
Bible texts, commentaries, dictionaries and books provided by the Crosswire
Bible Society.

BibleTime provides easy handling of digitalized texts (Bibles, commentaries and
lexicons) and powerful features to work with these texts (search in texts,
write own notes, save, print etc.).

%prep
%setup -q

%build
%cmake \
%if 0%{?suse_version} < 1600
  -DCMAKE_INSTALL_DOCDIR:PATH=%{_docdir}/%{name} \
%endif
  -DCMAKE_BUILD_TYPE=Release \
  -DBT_DOCBOOK_XSL_HTML_CHUNK_XSL=%{_datadir}/xml/docbook/stylesheet/nwalsh/current/html/chunk.xsl \
  -DBT_DOCBOOK_XSL_PDF_DOCBOOK_XSL=%{_datadir}/xml/docbook/stylesheet/nwalsh/current/fo/docbook.xsl
%cmake_build

%install
%cmake_install

%fdupes -s %{buildroot}

%suse_update_desktop_file -r %{buildroot}%{_datadir}/applications/info.%{name}.BibleTime.desktop Education Humanities

%files
%doc ChangeLog README.md
%license LICENSE
%{_bindir}/bibletime
%{_datadir}/icons/*
%{_datadir}/applications/info.%{name}.BibleTime.desktop
%dir %{_datadir}/bibletime
%{_datadir}/bibletime/*
%dir %{_docdir}/bibletime
%{_docdir}/bibletime/*
%{_datadir}/metainfo/info.bibletime.BibleTime.metainfo.xml

%changelog
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Align path for document installation between openSUSE versions.
* Sun May 15 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 3.0.3:
  * Fixed license.html being installed twice
  * Partially worked around a libsword bug which limited download durations to
    10 seconds
  * Fixed bug which made it impossible to active toolbar buttons using keyboard
  * Fixed some out-of-bounds memory read
  * Fixed a number of input parsing and output generation errors, including
    invalid memory reads
  * Fixed search scopes not being properly translated
  * Fixed version information in installed metadata files
  * Updated translations
* Mon Aug 30 2021 Cor Blom <cornelis@solcon.nl>
- Update to 3.0.2:
  * Fixed a build-error caused by an C++11 incompatibility (bug #332)
  * Fixed copying of text disabled with Qt versions earlier than than
    5.13 (bug #334)
  * Fixed some undefined behavior and out-of-bounds memory errors
  * Fixed missing documentation in Windows
  * Updated translations
  * Added ability to copy docs into build during install and packaging
* Sun Aug  8 2021 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 3.0.1:
  * Improved tuning of scrolling speed.
  * Improved handling of fonts to fix many bugs, including a switch to Qt's
    native font chooser widget in settings dialog, because of many serious bugs
    in our legacy implementation.
  * Improved sample text in settings dialog.
  * Improved behavior of the mag view to be more similar to pre-3.0 behavior.
  * Increased maximum column count from 4 to 10.
  * Removed the orphaned and broken tests for BibleTime.
  * Updated translations, including a new user interface translations to
    Japanese and Ukrainian, a new Handbook translation to Russian, and a new
    Howto translation to Ukrainian.
  * Fixed DisplayView.qml getting incorrectly installed under /usr/bin/ on some
    platforms.
  * Fixed some compatibility issues with different Qt versions.
  * Fixed a crash when editing personal commentary.
  * Fixed highlighting of selected text.
  * Fixed dragging of links.
  * Fixed modules rearranging themselves.
  * Fixed logic related to clicking on verse numbers.
  * Fixed custom font of first column being incorrectly applied to all columns.
  * Fixed preview in settings dialog displaying text in red.
  * Fixed lexicons not being displayed.
  * Fixed drag and drop in mag view and search dialog.
  * Fixed no text being displayed for some ThML modules.
  * Fixed undefined behavior and crashes from opening menus to select works by
    working around a broken QMenu interface (QTBUG-77273).
  * Fixes to handling of languages, including a caching discrepancy which
    caused some settings not being properly applied before restarting
    BibleTime.
  * Fixed saving of chapters not working properly.
  * Fixed handling of nested tags for OSIS works.
  * Fixes to handling of PageUp/PageDown keys when scrolling out of bounds.
    Note that when BibleTime is compiled against Qt 5.9, one might still
    experience a trivial glitch where only part of the module is displayed.
    Pressing PageUp/PageDown again may help to work around this.
- Remove displayview.patch
* Sun Jun 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Remove the unneeded QtWebKit build dependency.
* Fri Jan 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add compatibility with qml-autoreqprov
* Sun Aug 30 2020 Cor Blom <cornelis@solcon.nl>
- Update to 3.0:
  Enhancements:
  * Text windows now have continuous scrolling from the beginning
    to end of a module. At the end of a chapter just keep scrolling
    to see the next chapter.
  * You don't have to open the Personal Commentary for writing. Edit
    it in a normal text window or even when it is a parallel column in a text window.
  * Automatic text scrolling up or down with variable speed and pause.
  * Copy to clipboard by choosing the beginning and ending reference.
  * A search filter was added in the "Install Works" page of the
    Bookshelf Manager.
  * You can select text from a single column when using parallel
    texts in a window.
  * Added a user interface to delete or create search indices.
  * The first time the Bookshelf Manager is used in a session, the
    remote libraries are updated.
  * Improved popup menus and icons for module chooser buttons and
    text window headers.
  * Show module unlock information in about text when available.
  * Improved unlocking of modules.
  Bugs fixed:
  * Locked Bible not unlocking properly.
  * Place not being saved in Daily Devotional.
  * Problems with MAG window references using hebrew modules OSHB
    and OSMHB.
  * Unable to create a search scope for deuterocanonical books.
  * Searching with quotes not working.
  * MAG windows Strongs references not working unless config
    settings were saved.
- Add displayview.patch
* Mon Nov 18 2019 Simon Lees <sflees@suse.de>
- %%make_jobs is depricated replaced by %%cmake_build
* Sun Sep 15 2019 Cor Blom <cornelis@solcon.nl>
- Update desktop file categories
* Wed Sep 19 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description.
* Mon Sep 17 2018 Cor Blom <cornelis@solcon.nl>
- Update to 2.11.2:
  * Updated translations.
  * Improved compatibility with Qt 5.11 (including bug #140)
  * Fixed crash when clicking on "full syntax" (bug #134)
  * Fixed Mag not always working with Hebrew / Strongs (bug #132)
  * Fixed BibleTime startup on some versions of Windows (bug #119)
  * Fixed Bookshelf Wizard buttons not being translated (bug #131)
  * Fixed application icon directory to match the FreeDesktop standard
  * Fixed bug which prevented installing of works (bug #124)
* Thu Dec  7 2017 mpluskal@suse.com
- Drop useless provides/obsoletes
- Use cmake macros
- Use source for url
* Tue Dec  5 2017 cornelis@solcon.nl
- Update to 2.11.1:
  * Details: https://github.com/bibletime/bibletime/releases
- Swith to Qt5
- Cleanup spec file: remove line for other distros.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Wed Apr  8 2015 dimstar@opensuse.org
- No longer package bibletime.xpm: there are perfectly good icons
  inside the tarball (even in scalable svg format).
- Fix the installation location of the icon: ensure the real file
  is located in /usr/share/icons/[..].
* Mon Jul  7 2014 lars@linux-schulserver.de
- udpate to 2.10.1:
  * Implemented support for localized module config entries.
  * Fixed an OSIS rendering bug.
  * Fixed some HTML rendering issues.
  * Fixed key chooser bug in book windows.
  * Fixed double loading of some settings.
  * Fixed Text Filter settings not being saved.
  * Various install manager bug fixes.
  * Various other minor fixes and optimizations.
* Tue Dec 31 2013 lars@linux-schulserver.de
- update to 2.10.0:
  + Enhancements:
  ++ Uses Sword library version 1.7.
  ++ Added Find context menu for search within each window. Matching
    words are highlighted and navigated using next or previous buttons.
  ++ Added support for HTTP, HTTPS, SFTP transports in BibleTime.
  ++ Implemented saving of font family and size in HTML commentary editor.
  + Bugs fixed:
  ++ Fixed problem where certain alternate versification bibles did not
    display old testament.
  ++ Fixed Windows Control Panel version was to be correct.
  ++ Fixed search analysis save dialog filters.
  ++ Fixed search analysis save asking for overwrite confirmation twice.
  ++ Optimized and enhanced search analysis to output proper XHTML.
  ++ Fixed widget ending up disabled after removing install source.
  ++ Mag Window uses current module if no default cross reference is set.
  ++ Fixed a bug in the HTML commentary editor which resulted in text
    formatting from the cursor to be applied to the whole selection.
  ++ Allow comboxboxes on config dialog desk page to resize.
  ++ Fixed some lexicons never working.
  ++ Fixed high stack memory usage on indexing.
  ++ Fixed unexpected exception with encrypted modules.
  ++ Fixed application freeze during installation of works.
* Tue Jun  4 2013 lars@linux-schulserver.de
- update to 2.9.2:
  + Fixed settings dialog tab contents not being translated
  + Fix crash when closing window with tab
  + Fix bug 14 - Headers displayed as plain text in some modules
  + Fix problem with text not displaying when using QtWebKit 2.3
  + added changes needed for Qt5
  + Fix multi-arch path issue in FindCLucene.cmake
- removed fix-movetoanchor-for-qt5.patch (upstream)
* Fri May  3 2013 hrvoje.senjan@gmail.com
- Added fix-movetoanchor-for-qt5.patch, fixes non visible text when
  used with libQtWebkit 2.3
* Sat Dec 15 2012 lars@linux-schulserver.de
- specfile cleanup
- fix license to be in SPDX format
- fix build on Fedora and Mandriva
* Fri Dec 30 2011 lars@linux-schulserver.de
- update to 2.9.1:
  + Fixed Portuguese translation not being included.
  + Updated British translation.
  + Updated handbooks.
- Notable changes since the 2.8 series:
  + Add close buttons to tabbed works windows.
  + Hovering over works in the bookshelf views shows tooltips.
  + Hovering over works in the bookshelf dock shows info in the mag view.
  + Add toolbar icons to toggle visibility of docking windows.
  + Switch off footnotes in display options.
  + Bible windows can have parallel commentaries.
* Sat Sep 10 2011 lars@linux-schulserver.de
- update to 2.8.2:
  + Fixed bookshelf manager install page taking long to open.
  + Fix restoring from fullscreen to a maximized window.
  + Fixed Personal Commentary texts being saved to wrong
    references.
  + Fixed an assert-crash caused by not catching indexing failures
    properly.
* Sat Jan 29 2011 lars@linux-schulserver.de
- update to 2.8.1:
  + Fixed a bug which caused many works to be incorrectly categorized
  + Fixed a Bookshelf Manager crash caused by installation sources
    which provide invalid data
* Sat Dec 18 2010 lars@linux-schulserver.de
- update to 2.8.0:
  + Redesigned and refactored the bookshelf manager
  + Implemented the Tip Of The Day dialog
  + Made BibleTime handle missing default template gracefully
  + Made the "Remove modules" confirmation dialog a bit prettier
  + Fixed a crash triggered by an assertion in legacy code
  + Fix main window toolbar key changer to save a modified entry
    in Personal Commentary
* Thu Oct 21 2010 lars@linux-schulserver.de
- update to 2.7.3:
  + Backported "Fixed invalid bibletimerc creation; removed unused
    CResMgr::init_tr()." by Jaak Ristioja
  + Backported "Fix crash opening first window in manual arrangement
    mode." by Gary Holmlund.
  + Backported "Fixed a bug that caused some users home directories
    to be deleted" by Jaak Ristioja.
  + Backported "Save the "grouping" setting of the Bookshelf"
    by Gary Holmlund.
* Fri Jul  9 2010 lars@linux-schulserver.de
- update to 2.7:
  + Fix bug #2969498 : Resize bug in magnification area
  + Fix main window view menu so that shortcuts can be assigned
    to them.
  + Modified retranslateUi to work correctly with the shortcut
    editor
  + Add option to show toolbar on main window instead of
    text windows
* Sun Mar 28 2010 lars@linux-schulserver.de
- update to 2.6:
  + Fixed an issue causing data loss when closing the main window,
    because open sub-windows were not properly queried for unsaved
    changes.
  + Refactored the module unlocking GUI to provide more info on
    failures and made opening a locked module also initiate the
    unlocking procedure.
  + Fixed a bug that some display/filter settings were not applied
    on startup
  + Add tabbed window arrangement mode
  + Fix problems with manual arrangement mode
  + Implemented a menu item and tool button for opening installed works
  + Refactored a couple of other dialogs to use the new bookshelf model.
    This means they now also have search and grouping fields.
  + Refactored search dialog module chooser dialog
- removed all patches
* Sun Dec 20 2009 lars@linux-schulserver.de
- update to 2.5:
  + improvements to the subwindow arrangement algorithms
  ++ many bugfixes
  ++ new window arrangement modes "Tile" and "Auto Tile"
  + new module selection header in the text windows
  + tons of bugfixes
  + many improvements to the windows port
  + improved debug mode of the application
  + improvements to build system
  + translation updates
  + Christmas splash screen and display template
* Sun Dec 13 2009 lars@linux-schulserver.de
- update to 2.4:
  + many, many bugfixes
  + Improved search dialog
  + Added "get list of install sources from server" functionality
  + BibleTime can now open TEI modules
  + Added new feature called "Change location". It is a shortcut
    (Ctrl-L) that changes the focus to the toolbar field for the
    bible reference or book location.
    This is like the Ctrl-L feature of FireFox.
  + Add shortcut page to config settings dialog
- fix build for fedora
* Thu Jul 23 2009 lars@linux-schulserver.de
- update to 2.0.1:
  + Completed the port to QT. KDE is no longer required.
  + Use default browser instead of just konqueror or firefox.
  + Use docking windows instead of splitters for the left
    side windows.
  + Add Czech translation
  + Add Hungarian Handbook translation
  + Fix drag/drop onto the display window
  + Fix clicking of links in the Mag Window
  + Fix problem causing Mag window to update when it should not
- obsolete bibletime-i18n and bibletime-devel
* Thu Jul 23 2009 lars@linux-schulserver.de
- update to 1.7:
  + tons of bugfixes
  + Port to KDE4/QT4, reduced KDE dependency to a minimum
  + Command line options have changed (--help is out of date)
  + Configuration files have been moved to ~/.bibletime/
  + i18n of UI strings is now handled by QT
  + Massive code cleanups and internal refactoring
  + New bookshelf manager
  + New external communications interface DBUS (instead of DCOP)
  + many Bookshelf improvements
  + Corrections and enhancements to session management
  + Search dialog now has a history for the modules to search in
* Thu Jul 23 2009 lars@linux-schulserver.de
- added virtual provides: sword-frontend
* Mon Dec 15 2008 lars@linux-schulserver.de
- fix gcc 4.3.2 issues
  (bibletime-1.6.5.1-stringcompare.patch)
* Thu Jun 12 2008 lars@linux-schulserver.de
- added
  Recommends:     sword-bible
  Recommends:     sword-commentary
* Mon Jun  9 2008 lars@linux-schulserver.de
- update to 1.6.5.1:
  + bugfix release to build with current gcc
* Mon May 19 2008 lars@linux-schulserver.de
- fix rpm groups
* Sun Dec 23 2007 lars@linux-schulserver.de
- initial version 1.6.5
